@@ -9,7 +9,7 @@
 
 		http://www.netlib.org/f2c/libf2c.zip
 */
-
+#include "solve.QP.h"
 #include "f2c.h"
 #include <string.h>
 #include <stdlib.h>
@@ -19,8 +19,8 @@
 #include <sys/sysinfo.h>
 #include <unistd.h>
 
-const int true  = 0;
-const int false = 1;
+//int true  = 0;
+//int false = 1;
 
 /*  Copyright (C) 1995-2010 Berwin A. Turlach <Berwin.Turlach@gmail.com> */
 
@@ -145,7 +145,7 @@ const int false = 1;
     --work;
 
     /* Function Body */
-    r__ = min(*n,*q);
+    r__ = fmin(*n,*q);
     l = (*n << 1) + r__ * (r__ + 5) / 2 + (*q << 1) + 1;
 
 /*     code gleaned from Powell's ZQPCVX routine to determine a small */
@@ -548,11 +548,11 @@ L100:
 /* Computing MAX */
 		    d__3 = (d__1 = work[i__ - 1], abs(d__1)), d__4 = (d__2 = 
 			    work[i__], abs(d__2));
-		    gc = max(d__3,d__4);
+		    gc = fmax(d__3,d__4);
 /* Computing MIN */
 		    d__3 = (d__1 = work[i__ - 1], abs(d__1)), d__4 = (d__2 = 
 			    work[i__], abs(d__2));
-		    gs = min(d__3,d__4);
+		    gs = fmin(d__3,d__4);
 		    d__1 = gc * sqrt(gs * gs / (gc * gc) + 1);
 		    temp = d_sign(&d__1, &work[i__ - 1]);
 		    gc = work[i__ - 1] / temp;
@@ -664,11 +664,11 @@ L797:
 /* Computing MAX */
     d__3 = (d__1 = work[l1 - 1], abs(d__1)), d__4 = (d__2 = work[l1], abs(
 	    d__2));
-    gc = max(d__3,d__4);
+    gc = fmax(d__3,d__4);
 /* Computing MIN */
     d__3 = (d__1 = work[l1 - 1], abs(d__1)), d__4 = (d__2 = work[l1], abs(
 	    d__2));
-    gs = min(d__3,d__4);
+    gs = fmin(d__3,d__4);
     d__1 = gc * sqrt(gs * gs / (gc * gc) + 1);
     temp = d_sign(&d__1, &work[l1 - 1]);
     gc = work[l1 - 1] / temp;
@@ -1005,7 +1005,7 @@ void wrap_polyhedron_thread_task(double** traces,double* C_f,double *b,double* r
     sol = (double*)calloc(n*1,sizeof(double));
     lagr = (double*)calloc(m,sizeof(double));
     iact = (int*)calloc(m,sizeof(int));
-    work = (double*)calloc(2*n+min(n, m)*(min(n, m)+5)/2 + 2*m +1,sizeof(double));
+    work = (double*)calloc(2*n+fmin(n, m)*(fmin(n, m)+5)/2 + 2*m +1,sizeof(double));
     
     //memcpy(C,C_f,m*n*sizeof(double));
     
@@ -1025,7 +1025,7 @@ void wrap_polyhedron_thread_task(double** traces,double* C_f,double *b,double* r
         memset(sol,0,n*sizeof(double));
         memset(lagr,0,m*sizeof(double));
         memset(iact,0,m*sizeof(int));
-        memset(work,0,(2*n+min(n, m)*(min(n, m)+5)/2 + 2*m +1) * sizeof(double));
+        memset(work,0,(2*n+fmin(n, m)*(fmin(n, m)+5)/2 + 2*m +1) * sizeof(double));
         memset(G, 0 , n*n*sizeof(double));    
         memset(A_t_trace,0,m*sizeof(double));
         
@@ -1100,7 +1100,7 @@ void wrap_polyhedron_threaded(double** traces,double* C_f,double *b,double* resu
     }
 }
 
-void wrap_polyhedron_two(double* traces,double* C_f,double *b,double* results,int m_in , int n_in,long length){
+void wrap_polyhedron_two(double** traces,double* C_f,double *b,double* results,int m_in , int n_in,long length){
     double* a;
     int ierr;
     int meq;
@@ -1165,7 +1165,7 @@ void wrap_polyhedron_two(double* traces,double* C_f,double *b,double* results,in
     sol = (double*)calloc(n*1,sizeof(double));
     lagr = (double*)calloc(m,sizeof(double));
     iact = (int*)calloc(m,sizeof(int));
-    work = (double*)calloc(2*n+min(n, m)*(min(n, m)+5)/2 + 2*m +1,sizeof(double));
+    work = (double*)calloc(2*n+fmin(n, m)*(fmin(n, m)+5)/2 + 2*m +1,sizeof(double));
     
     //memcpy(C,C_f,m*n*sizeof(double));
     
@@ -1185,7 +1185,7 @@ void wrap_polyhedron_two(double* traces,double* C_f,double *b,double* results,in
         memset(sol,0,n*sizeof(double));
         memset(lagr,0,m*sizeof(double));
         memset(iact,0,m*sizeof(int));
-        memset(work,0,(2*n+min(n, m)*(min(n, m)+5)/2 + 2*m +1) * sizeof(double));
+        memset(work,0,(2*n+fmin(n, m)*(fmin(n, m)+5)/2 + 2*m +1) * sizeof(double));
         memset(G, 0 , n*n*sizeof(double));    
         memset(A_t_trace,0,m*sizeof(double));
         
@@ -1200,8 +1200,7 @@ void wrap_polyhedron_two(double* traces,double* C_f,double *b,double* results,in
         }
     
         //Multiply the current A by the current trace to see if we are calculating depth or distance
-        printf("First %lf \n",traces[i*m + 2]);
-        matmulcol(C_f_temp,m,n,&traces[m*i],n,1,A_t_trace);
+        matmulcol(C_f_temp,m,n,traces[i],n,1,A_t_trace);
         
         
         
@@ -1217,26 +1216,23 @@ void wrap_polyhedron_two(double* traces,double* C_f,double *b,double* results,in
             
         //}
         
-        if(!matlessthaneq(A_t_trace,b,m,1)){
-            results[i] = calc_depth(C_f,b,&traces[m*i],m,n);
+        if(matlessthaneq(A_t_trace,b,m,1)){
+            results[i] = calc_depth(C_f,b,traces[i],m,n);
         }else{
             // Subtract A*x from b (b - A*x) 
             matsub(b_sub,m,1,A_t_trace,m,1);
             //Flip sign because qpgen works with Ax >= b
             matscaler(-1.0,b_sub,m,1);
             matscaler(-1.0,C_f_temp,m,n);
-
+                
             //Transpse A to be used with qpgen
             transpose(C_f_temp,m,n , C_t);
             
-            
             qpgen2_(G,a,&n,&n,sol,lagr,&results[i],C_t,b_sub,&n,&m,&meq,iact,&nact,iters,work,&ierr);
             results[i] = -1*sqrt(2*results[i]);
-            
         }
-        
+        free(traces[i]);
     }
-    free(traces);
     //printf("ierr: %d\n" ,ierr);
     //printf("DONE\n");
 }
